package com.willalp.event.service.impl;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.willalp.common.core.domain.ReturnEntity;
import com.willalp.common.exception.base.BaseException;
import com.willalp.common.utils.ObjectToTypes;
import com.willalp.common.utils.StringUtils;
import com.willalp.event.domain.HsWelfareApplyRecord;
import com.willalp.event.mapper.HsWelfareApplyRecordMapper;
import com.willalp.event.service.IHsWelfareApplyRecordService;
import org.springframework.stereotype.Service;

import javax.annotation.Resource;
import java.util.ArrayList;
import java.util.List;

/**
 * 福利报名记录Service业务层处理
 *
 * @author willalp
 * @date 2023-04-17
 */
@Service
public class HsWelfareApplyRecordServiceImpl extends ServiceImpl<HsWelfareApplyRecordMapper, HsWelfareApplyRecord> implements IHsWelfareApplyRecordService {
    @Resource
    private HsWelfareApplyRecordMapper hsWelfareApplyRecordMapper;

    /**
     * 查询福利报名记录列表
     *
     * @param hsWelfareApplyRecord 福利报名记录
     * @return 福利报名记录
     */
    @Override
    public List<HsWelfareApplyRecord> selectHsWelfareApplyRecordList(HsWelfareApplyRecord hsWelfareApplyRecord) {
        return hsWelfareApplyRecordMapper.selectHsWelfareApplyRecordList(hsWelfareApplyRecord);
    }

    @Override
    public String importData(List<HsWelfareApplyRecord> list, String fileName) {
        if (StringUtils.isBlank(fileName)) {
            if (count(new QueryWrapper<HsWelfareApplyRecord>().eq("source", fileName)) > 0) {
                throw new BaseException("该Excel已经存在");
            }
        }
        int successNum = 0;
        int failureNum = 0;
        List<HsWelfareApplyRecord> toSaveList = new ArrayList<>();
        for (HsWelfareApplyRecord welfareApplyRecord : list) {
            try {
                if (StringUtils.isBlank(welfareApplyRecord.getUserCode())) {
                    throw new Exception();
                }
                if (StringUtils.isBlank(welfareApplyRecord.getUserName())) {
                    throw new Exception();
                }
                welfareApplyRecord.setSource(fileName);
                toSaveList.add(welfareApplyRecord);
            } catch (Exception e) {
                failureNum++;
                log.error(e.getMessage(), e);
            }
        }
        if (saveBatch(toSaveList)) {
            successNum = toSaveList.size();
        }
        ReturnEntity<String> res = new ReturnEntity<>();
        res.setReturnMessage("event.club.successCode", new String[]{
                ObjectToTypes.parseString(successNum), ObjectToTypes.parseString(failureNum)
        });
        return res.getMessage();
    }


}
